import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class AppTheme {
  // Colores base
  static Color primary = const Color(0xFF32D7ED);
  static Color secondary = Colors.black;
  static Color tertiary = const Color(0xFF242424);
  static Color quaternary = const Color(0xFFF1F1F3);
  static Color verde = const Color(0xff248f83);
  static Color rojo = const Color(0xFFF24B59);

  // Tema Claro
  static ThemeData lightTheme = ThemeData.light().copyWith(
    scaffoldBackgroundColor: const Color(0xFFE0E0E0),
    appBarTheme: AppBarTheme(
      color: primary,
      foregroundColor: secondary,
      systemOverlayStyle: SystemUiOverlayStyle(
        statusBarColor: primary,
        statusBarIconBrightness: Brightness.dark,
      ),
      iconTheme: IconThemeData(color: secondary),
    ),
    floatingActionButtonTheme: FloatingActionButtonThemeData(
      backgroundColor: primary,
      foregroundColor: secondary,
    ),
    progressIndicatorTheme: ProgressIndicatorThemeData(color: tertiary),
    datePickerTheme: DatePickerThemeData(
      backgroundColor: const Color(0xFFDBDBDB),
      headerBackgroundColor: primary,
      todayBackgroundColor: const MaterialStatePropertyAll(Color(0xFFDBDBDB)),
      todayForegroundColor: const MaterialStatePropertyAll(Colors.black),
      rangePickerBackgroundColor: secondary,
    ),
  );

  //  **Tema Oscuro**
  static ThemeData darkTheme = ThemeData.dark().copyWith(
    scaffoldBackgroundColor: const Color(0xFF121212),
    appBarTheme: AppBarTheme(
      color: tertiary, // Un gris oscuro
      foregroundColor: Colors.white,
      systemOverlayStyle: SystemUiOverlayStyle(
        statusBarColor: tertiary,
        statusBarIconBrightness: Brightness.light,
      ),
      iconTheme: const IconThemeData(color: Colors.white),
    ),
    floatingActionButtonTheme: FloatingActionButtonThemeData(
      backgroundColor: primary,
      foregroundColor: Colors.black,
    ),
    progressIndicatorTheme: ProgressIndicatorThemeData(color: primary),
    datePickerTheme: DatePickerThemeData(
      backgroundColor: tertiary,
      headerBackgroundColor: primary,
      todayBackgroundColor: const MaterialStatePropertyAll(Colors.white24),
      todayForegroundColor: const MaterialStatePropertyAll(Colors.white),
      rangePickerBackgroundColor: secondary,
    ),
  );
}
